==> devextreme-23.1.13.tgz: package/renovation/ui/scheduler/workspaces/props.js <==
/**
 * DevExtreme (renovation/ui/scheduler/workspaces/props.js)
 * Version: 23.1.13
 * Build date: Mon Oct 28 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.WorkSpaceProps = exports.CurrentViewConfigType = void 0;
var _date = _interopRequireDefault(require("../../../../core/utils/date"));
var _base_props = require("../../common/base_props");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
var DEFAULT_GROUPS = [];
var WorkSpaceProps = Object.create(Object.prototype, _extends(Object.getOwnPropertyDescriptors(_base_props.BaseWidgetProps), Object.getOwnPropertyDescriptors(Object.defineProperties({
    intervalCount: 1,
    groups: DEFAULT_GROUPS,
    groupByDate: false,
    crossScrollingEnabled: false,
    startDayHour: 0,
    endDayHour: 24,
    firstDayOfWeek: 0,
    hoursInterval: .5,
    showAllDayPanel: false,
    allDayPanelExpanded: false,
    allowMultipleCellSelection: true,
    indicatorTime: Object.freeze(new Date),
    today: Object.freeze(new Date),
    shadeUntilCurrentTime: true,
    selectedCellData: Object.freeze([]),
    scrolling: Object.freeze({
        mode: "standard"
    }),
    cellDuration: 30,
    showCurrentTimeIndicator: true,
    type: "week",
    allDayPanelMode: "all"
}, {
    indicatorUpdateInterval: {
        get: function() {
            return 5 * _date.default.dateToMilliseconds("minute")
        },
        configurable: true,
        enumerable: true
    }
}))));
exports.WorkSpaceProps = WorkSpaceProps;
var CurrentViewConfigType = Object.defineProperties({}, {
    intervalCount: {
        get: function() {
            return WorkSpaceProps.intervalCount
        },
        configurable: true,
        enumerable: true
    },
    groupByDate: {
        get: function() {
            return WorkSpaceProps.groupByDate
        },
        configurable: true,
        enumerable: true
    },
    crossScrollingEnabled: {
        get: function() {
            return WorkSpaceProps.crossScrollingEnabled
        },
        configurable: true,
        enumerable: true
    },
    startDayHour: {
        get: function() {
            return WorkSpaceProps.startDayHour
        },
        configurable: true,
        enumerable: true
    },
    endDayHour: {
        get: function() {
            return WorkSpaceProps.endDayHour
        },
        configurable: true,
        enumerable: true
    },
    firstDayOfWeek: {
        get: function() {
            return WorkSpaceProps.firstDayOfWeek
        },
        configurable: true,
        enumerable: true
    },
    hoursInterval: {
        get: function() {
            return WorkSpaceProps.hoursInterval
        },
        configurable: true,
        enumerable: true
    },
    showAllDayPanel: {
        get: function() {
            return WorkSpaceProps.showAllDayPanel
        },
        configurable: true,
        enumerable: true
    },
    allDayPanelExpanded: {
        get: function() {
            return WorkSpaceProps.allDayPanelExpanded
        },
        configurable: true,
        enumerable: true
    },
    allowMultipleCellSelection: {
        get: function() {
            return WorkSpaceProps.allowMultipleCellSelection
        },
        configurable: true,
        enumerable: true
    },
    indicatorUpdateInterval: {
        get: function() {
            return WorkSpaceProps.indicatorUpdateInterval
        },
        configurable: true,
        enumerable: true
    },
    shadeUntilCurrentTime: {
        get: function() {
            return WorkSpaceProps.shadeUntilCurrentTime
        },
        configurable: true,
        enumerable: true
    },
    scrolling: {
        get: function() {
            return WorkSpaceProps.scrolling
        },
        configurable: true,
        enumerable: true
    },
    cellDuration: {
        get: function() {
            return WorkSpaceProps.cellDuration
        },
        configurable: true,
        enumerable: true
    },
    showCurrentTimeIndicator: {
        get: function() {
            return WorkSpaceProps.showCurrentTimeIndicator
        },
        configurable: true,
        enumerable: true
    },
    type: {
        get: function() {
            return WorkSpaceProps.type
        },
        configurable: true,
        enumerable: true
    },
    allDayPanelMode: {
        get: function() {
            return WorkSpaceProps.allDayPanelMode
        },
        configurable: true,
        enumerable: true
    },
    focusStateEnabled: {
        get: function() {
            return WorkSpaceProps.focusStateEnabled
        },
        configurable: true,
        enumerable: true
    },
    tabIndex: {
        get: function() {
            return WorkSpaceProps.tabIndex
        },
        configurable: true,
        enumerable: true
    }
});
exports.CurrentViewConfigType = CurrentViewConfigType;

==> devextreme-23.2.3.tgz: package/renovation/ui/scheduler/workspaces/props.js <==
/**
 * DevExtreme (renovation/ui/scheduler/workspaces/props.js)
 * Version: 23.2.3
 * Build date: Tue Nov 28 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.WorkSpaceProps = exports.CurrentViewConfigType = void 0;
var _date = _interopRequireDefault(require("../../../../core/utils/date"));
var _base_props = require("../../common/base_props");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
const DEFAULT_GROUPS = [];
const WorkSpaceProps = Object.create(Object.prototype, _extends(Object.getOwnPropertyDescriptors(_base_props.BaseWidgetProps), Object.getOwnPropertyDescriptors(Object.defineProperties({
    intervalCount: 1,
    groups: DEFAULT_GROUPS,
    groupByDate: false,
    crossScrollingEnabled: false,
    startDayHour: 0,
    endDayHour: 24,
    viewOffset: 0,
    firstDayOfWeek: 0,
    hoursInterval: .5,
    showAllDayPanel: false,
    allDayPanelExpanded: false,
    allowMultipleCellSelection: true,
    indicatorTime: Object.freeze(new Date),
    shadeUntilCurrentTime: true,
    selectedCellData: Object.freeze([]),
    scrolling: Object.freeze({
        mode: "standard"
    }),
    cellDuration: 30,
    showCurrentTimeIndicator: true,
    type: "week",
    allDayPanelMode: "all"
}, {
    indicatorUpdateInterval: {
        get: function() {
            return 5 * _date.default.dateToMilliseconds("minute")
        },
        configurable: true,
        enumerable: true
    }
}))));
exports.WorkSpaceProps = WorkSpaceProps;
const CurrentViewConfigType = Object.defineProperties({}, {
    intervalCount: {
        get: function() {
            return WorkSpaceProps.intervalCount
        },
        configurable: true,
        enumerable: true
    },
    groupByDate: {
        get: function() {
            return WorkSpaceProps.groupByDate
        },
        configurable: true,
        enumerable: true
    },
    crossScrollingEnabled: {
        get: function() {
            return WorkSpaceProps.crossScrollingEnabled
        },
        configurable: true,
        enumerable: true
    },
    startDayHour: {
        get: function() {
            return WorkSpaceProps.startDayHour
        },
        configurable: true,
        enumerable: true
    },
    endDayHour: {
        get: function() {
            return WorkSpaceProps.endDayHour
        },
        configurable: true,
        enumerable: true
    },
    firstDayOfWeek: {
        get: function() {
            return WorkSpaceProps.firstDayOfWeek
        },
        configurable: true,
        enumerable: true
    },
    hoursInterval: {
        get: function() {
            return WorkSpaceProps.hoursInterval
        },
        configurable: true,
        enumerable: true
    },
    showAllDayPanel: {
        get: function() {
            return WorkSpaceProps.showAllDayPanel
        },
        configurable: true,
        enumerable: true
    },
    allDayPanelExpanded: {
        get: function() {
            return WorkSpaceProps.allDayPanelExpanded
        },
        configurable: true,
        enumerable: true
    },
    allowMultipleCellSelection: {
        get: function() {
            return WorkSpaceProps.allowMultipleCellSelection
        },
        configurable: true,
        enumerable: true
    },
    indicatorUpdateInterval: {
        get: function() {
            return WorkSpaceProps.indicatorUpdateInterval
        },
        configurable: true,
        enumerable: true
    },
    shadeUntilCurrentTime: {
        get: function() {
            return WorkSpaceProps.shadeUntilCurrentTime
        },
        configurable: true,
        enumerable: true
    },
    scrolling: {
        get: function() {
            return WorkSpaceProps.scrolling
        },
        configurable: true,
        enumerable: true
    },
    cellDuration: {
        get: function() {
            return WorkSpaceProps.cellDuration
        },
        configurable: true,
        enumerable: true
    },
    showCurrentTimeIndicator: {
        get: function() {
            return WorkSpaceProps.showCurrentTimeIndicator
        },
        configurable: true,
        enumerable: true
    },
    type: {
        get: function() {
            return WorkSpaceProps.type
        },
        configurable: true,
        enumerable: true
    },
    allDayPanelMode: {
        get: function() {
            return WorkSpaceProps.allDayPanelMode
        },
        configurable: true,
        enumerable: true
    },
    focusStateEnabled: {
        get: function() {
            return WorkSpaceProps.focusStateEnabled
        },
        configurable: true,
        enumerable: true
    },
    tabIndex: {
        get: function() {
            return WorkSpaceProps.tabIndex
        },
        configurable: true,
        enumerable: true
    }
});
exports.CurrentViewConfigType = CurrentViewConfigType;
